# Import der benötigten Module
from microbit import *
from neopixel import *
import radio

# Initalisierung der RGB LEDs
np = NeoPixel(pin0, 8)

# Einschalten der Funkhardware
radio.on()

# Vordefinitionen für die Beleuchtung
headlights = (0, 3)
backlights = (5, 6)
led_white = (60, 60, 60)
led_red = (60, 0, 0)
led_off = (0, 0, 0)

# Funktion um die Motoren zu steuern
def drive(PWM0, PWM1, PWM2, PWM3):
    i2c.write(0x70, b'\x02' + bytes([PWM0]))
    i2c.write(0x70, b'\x03' + bytes([PWM1]))
    i2c.write(0x70, b'\x04' + bytes([PWM2]))
    i2c.write(0x70, b'\x05' + bytes([PWM3]))

# Abblendlicht einschalten
def lightsON():
    for x in headlights:
        np[x] = led_white
    for x in backlights:
        np[x] = led_red
    np.show()

# Licht ausschalten
def lightsOFF():
    for x in headlights:
        np[x] = led_off
    for x in backlights:
        np[x] = led_off
    np.show()


# Steuerungsschleife
while True:
    incoming = radio.receive() # Empfang über Funkhardware wird in der Variable incoming abgelegt
    if incoming != None: # wenn incoming ist nicht None (leer) dann:
        if incoming[0] == "l": # Abfrage des 1. Zeichens für die Richtung
            drive(0, 0, 40, 255)
        elif incoming[0] == "r":
            drive(40, 255, 0, 0)
        elif incoming[0] == "f":
            drive(40, 255, 40, 255)
        elif incoming[0] == "b":
            drive(255, 40, 255, 40)
        else:
            drive(0, 0, 0, 0)

        if incoming[0] == "b": # ein und ausschalten des Rückfahrlichts
            np[4] = (led_white)
            np.show()
        else:
            np[4] = (led_off)
            np.show()

        if incoming[1] == "a": # Abfrage des 2. Zeichens für die Funktionen (Licht und Hupe)
#            music.play("c4:1", pin=pin16)
        elif incoming[1] == "b":
            lightsON()
        elif incoming[1] == "c":
            lightsON()
        else:
            lightsOFF()

    else: # wenn incoming = None, dann wird das Joy-Car geparkt. Dies ist in der Regel der Fall, wenn das Joy-Car ausserhalb der Reichweite der Fernbedienung ist oder wenn die Fernbedienung aus ist.
        drive(0, 0, 0, 0)
        for x in range(0, 8):
            np[x] = (50, 0, 0)
        np.show()